@@ -3,7 +3,7 @@ use warnings;
 
 package WebService::Shippo;
 # ABSTRACT: A Shippo Perl API wrapper
-our $VERSION = '0.0.19';
+our $VERSION = '0.0.20';
 require WebService::Shippo::Entities;
 use boolean ':all';
 use Params::Callbacks ( 'callbacks', 'callback' );
@@ -19,26 +19,19 @@ our @EXPORT = qw(
 sub import
 {
     my ( $class ) = @_;
-    # Configure Shippo client on import
     WebService::Shippo::Config->config;
-    # The API key is overridden with the environment's value if defined.
     WebService::Shippo::Resource->api_credentials(
         @ENV{ 'SHIPPO_USER', 'SHIPPO_PASS' } )
         if $ENV{SHIPPO_USER} && !$ENV{SHIPPO_TOKEN};
     WebService::Shippo::Resource->api_key( $ENV{SHIPPO_TOKEN} )
         if $ENV{SHIPPO_TOKEN};
-    # Pass call frame to Exporter's import for further processing
     goto &Exporter::import;
 }
 
 BEGIN {
     no warnings 'once';
-    # There are some useful symbols defined elsewhere that I'd like to
-    # make available (alias) via the root namespace.
     *api_key         = *WebService::Shippo::Resource::api_key;
     *api_credentials = *WebService::Shippo::Resource::api_credentials;
-    *pretty          = *WebService::Shippo::Object::pretty;
-    *response        = *WebService::Shippo::Request::response;
     *Shippo::        = *WebService::Shippo::;
 }
 
@@ -59,7 +52,7 @@ WebService::Shippo - Shippo API Client
 
 =head1 VERSION
 
-version 0.0.19
+version 0.0.20
 
 =head1 SYNOPIS
 
@@ -146,7 +139,7 @@ very long. Use it, or don't use it. It's entirely up to you.
     
     # Print the transaction object...
     
-    print "Transaction:\n", $transaction->to_json(1); # '1' makes the JSON readable
+    print "Transaction:\n", $transaction;
 
     --[content dumped to console]--
     Transaction:
@@ -187,9 +180,7 @@ very long. Use it, or don't use it. It's entirely up to you.
     }
     --[end of content]--
 
-The sample code in this synopsis produced the following label (at a much
-larger size, of course), which was then saved as a PNG file using the
-C<LWP::UserAgent> package:
+The sample code in this synopsis produced the following label:
 
 =over 2
 
@@ -215,32 +206,31 @@ attempts to correct that omission ;-)
 =head2 API Resources
 
 Access to all Shippo API resources is via URLs relative to the same encrypted
-API endpoint (https://api.goshippo.com/v1/).
-
-There are resource item classes to help with the nitty-gritty of interacting
-each type of resource:
+API endpoint (https://api.goshippo.com/v1/). The client provides object and
+collection classes to help with the nitty-gritty of dealing with those
+resources:
 
 =over 2
 
-=item * Addresses
+=item * L<Addresses|WebService::Shippo::Address>
 
-=item * Parcels
+=item * L<Parcels|WebService::Shippo::Parcel>
 
-=item * Shipments
+=item * L<Shipments|WebService::Shippo::Shipment>
 
-=item * Rates
+=item * L<Rates|WebService::Shippo::Rate>
 
-=item * Transactions
+=item * L<Transactions|WebService::Shippo::Transaction>
 
-=item * Customs Items
+=item * L<Customs Items|WebService::Shippo::CustomsItem>
 
-=item * Customs Declarations
+=item * L<Customs Declarations|WebService::Shippo::CustomsDeclaration>
 
-=item * Refunds
+=item * L<Refunds|WebService::Shippo::Refund>
 
-=item * Manifests
+=item * L<Manifests|WebService::Shippo::Manifest>
 
-=item * Carrier Accounts
+=item * L<Carrier Accounts|WebService::Shippo::CarrierAccount>
 
 =back
 
@@ -276,6 +266,89 @@ an object, you cannot change it. Instead, create a new one with the desired
 values. Carrier Accounts are the exception and may be updated via B<PUT>
 requests.
 
+=head1 OBJECTS vs COLLECTIONS
+
+Whereas a GET request to L<https://api.goshippo.com/v1/addresses/d799c2679e644279b59fe661ac8fa488>
+might produce a single address whose structure would resemble this:
+
+    {
+       "object_state":"VALID",
+       "object_purpose":"PURCHASE",
+       "object_source":"FULLY_ENTERED",
+       "object_created":"2014-07-09T02:19:13.174Z",
+       "object_updated":"2014-07-09T02:19:13.174Z",
+       "object_id":"d799c2679e644279b59fe661ac8fa488",
+       "object_owner":"shippotle@goshippo.com",
+       "name":"Shawn Ippotle",
+       "street1":"215 Clayton St.",
+       "street2":"",
+       "city":"San Francisco",
+       "state":"CA",
+       "zip":"94117",
+       "country":"US",
+       "phone":"15553419393",
+       "email":"shippotle@goshippo.com",
+       "ip":null,
+       "is_residential":true,
+       "messages":[],
+       "metadata":"Customer ID 123456"
+    }
+
+A GET request to L<https://api.goshippo.com/v1/addresses/> might produce a
+collection of address objects whose structure would resemble this:
+
+    {
+       "count":3,
+       "next":null,
+       "previous":null,
+       "results":[
+          {
+             "object_state":"VALID",
+             "object_purpose":"PURCHASE",
+             "object_source":"FULLY_ENTERED",
+             "object_created":"2014-07-16T23:20:31.089Z",
+             "object_updated":"2014-07-16T23:20:31.089Z",
+             "object_id":"747207de2ba64443b645d08388d0309c",
+             "object_owner":"shippotle@goshippo.com",
+             "name":"Shawn Ippotle",
+             "street1":"215 Clayton St.",
+             "street2":"",
+             "city":"San Francisco",
+             "state":"CA",
+             "zip":"94117",
+             "country":"US",
+             "phone":"15553419393",
+             "email":"shippotle@goshippo.com",
+             "is_residential":true,
+             "ip":null,
+             "messages":[
+    
+             ],
+             "metadata":"Customer ID 123456"
+          },
+          {...},
+          {...}
+       ]
+    }
+
+The Shippo API does not distinguish between a single object and a collection
+of objects. It deals purely with JSON strings and both object and collection
+are notionally considered to be the same type of object.
+
+Nevertheless, the Perl client B<does> distinguish between a single object and
+a collection of objects. For each API resource, the client defines an I<Item
+Class> (e.g. C<L<WebService::Shippo::Address>>) and a corresponding
+I<Collection Class> (e.g. C<L<WebService::Shippo::Addresses>>). The name of
+the collection class is always the plural form of the item class. Furthermore,
+any objects making up the C<results> of a collection will be blessed as 
+instances of the appropriate item class.
+
+Both item and collection classes implement different interfaces, but they
+also exhibit common behaviours. Collection classes will respond to methods
+that aid item access and cursor navigation, while both types of class respond
+(where appropriate) to C<create>, C<update>, C<fetch>, C<all>, C<iterate> and
+C<collect> methods.
+
 =head1 METHODS
 
 =head2 api_key
@@ -324,35 +397,6 @@ client will always favour token-based authentication. If C<api_key> and
 C<api_credentials> are both set manually then it is the most recently
 set mechanism that defines the HTTP Authorization header.
 
-=head2 pretty
-
-Get or set the state of the attribute influencing the default readability
-of objects serialized as JSON using the C<to_json> method or automatic
-stringification.
-
-=over 2
-
-=item * Return the current state of the C<pretty> attribute.
- 
-
-    my $boolean = Shippo->pretty;
-
-=item * Set the state of the C<pretty> attribute.
-
-    Shippo->pretty($boolean);
-
-=back
-
-B<Note>: the C<to_json> method also takes optional boolean argument that
-may be set to C<true> or C<false> to achieve the same effect for a single
-serialization, regardless of the default currently in force.
- 
-=head2 response
-
-    my $last_response = Shippo->response;
-
-Returns a copy of the C<L<HTTP::Response>> resulting from the most recent request.
-
 =head1 EXPORTS
 
 The C<WebService::Shippo> package exports a number of helpful subroutines by
@@ -408,13 +452,12 @@ See Ingy's L<boolean> package for more guidance.
 
 =head2 callback
 
-    Shippo::CarrierAccounts->all(callback {
-        $_->enable_test_mode;
-    });
+    $put_all_accounts_in_test_mode = Shippo::CarrierAccounts->collect( 
+        callback { shift->enable_test_mode } );
+    $put_all_accounts_in_test_mode->();
     
-Returns a blessed C<sub> suitable for use as a callback. Some methods accept
-optional blocking callbacks in order to facilitate list transformations, so
-this package makes C<&Params::Callbacks::callback> available for use.
+Many of the Perl client's methods allow the use of lambda functions for
+block operations and filtration.
 
 See L<Params::Callbacks> for more guidance.
 
@@ -462,73 +505,17 @@ which are found on your L<Shippo API page|https://goshippo.com/user/apikeys/>.
 
 =item * For API documentation, go to L<https://goshippo.com/docs/>
 
-=item * For API support, contact L<mailto:support@goshippo.com> with any 
+=item * For API support, contact L<support@goshippo.com|mailto:support@goshippo.com> with any 
 questions.
 
 =back
 
-=head1 SEE ALSO
-
-=head2 Shippo Objects
-
-=over 2
-
-=item * L<WebService::Shippo::Address>
-
-=item * L<WebService::Shippo::Parcel>
-
-=item * L<WebService::Shippo::Shipment>
-
-=item * L<WebService::Shippo::Rate>
-
-=item * L<WebService::Shippo::Transaction>
-
-=item * L<WebService::Shippo::CustomsItem>
-
-=item * L<WebService::Shippo::CustomsDeclaration>
-
-=item * L<WebService::Shippo::Refund>
-
-=item * L<WebService::Shippo::Manifest>
-
-=item * L<WebService::Shippo::CarrierAccount>
-
-=back
-
-=head2 Shippo Collections
-
-=over 2
-
-=item * L<WebService::Shippo::Addresses>
-
-=item * L<WebService::Shippo::Parcels>
-
-=item * L<WebService::Shippo::Shipments>
-
-=item * L<WebService::Shippo::Rates>
-
-=item * L<WebService::Shippo::Transactions>
-
-=item * L<WebService::Shippo::CustomsItems>
-
-=item * L<WebService::Shippo::CustomsDeclarations>
-
-=item * L<WebService::Shippo::Refunds>
-
-=item * L<WebService::Shippo::Manifests>
-
-=item * L<WebService::Shippo::CarrierAccounts>
-
-=back
-
 =head1 REPOSITORY
 
 =over 2
 
 =item * L<https://github.com/cpanic/WebService-Shippo>
 
-=item * L<https://github.com/cpanic/WebService-Shippo/wiki>
-
 =back
 
 =head1 AUTHOR
